@@ -168,7 +168,7 @@ gog_styled_object_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	style->interesting_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL; /* default */
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
-		style, GOG_OBJECT (gso), 0, FALSE);
+		style, GOG_OBJECT (gso), 0, style->interesting_fields);
 }
 
 static void
