@@ -27,6 +27,7 @@
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-path.h>
+#include <goffice/utils/go-styled-object.h>
 
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
@@ -41,7 +42,7 @@ gog_surface_plot_build_matrix (GogXYZPlot const *plot, gboolean *cardinality_cha
 	unsigned i, j;
 	double val;
 	GogSeries *series = GOG_SERIES (plot->base.series->data);
-	GODataMatrix *mat = GO_DATA_MATRIX (series->values[2].data);
+	GOData *mat = series->values[2].data;
 	unsigned n = plot->rows * plot->columns;
 	double *data;
 
@@ -49,7 +50,7 @@ gog_surface_plot_build_matrix (GogXYZPlot const *plot, gboolean *cardinality_cha
 
 	for (i = 0; i < plot->rows; i++)
 		for (j = 0; j < plot->columns; j++) {
-			val = go_data_matrix_get_value (mat, i, j);
+			val = go_data_get_matrix_value (mat, i, j);
 			if (plot->transposed)
 				data[j * plot->rows + i] = val;
 			else
@@ -79,7 +80,7 @@ gog_surface_plot_class_init (GogSurfacePlotClass *klass)
 
 	/* Fill in GogPlotClass methods */
 	gog_plot_klass->axis_set = GOG_AXIS_SET_XYZ;
-	gog_plot_klass->desc.series.style_fields = GOG_STYLE_LINE | GOG_STYLE_FILL;
+	gog_plot_klass->desc.series.style_fields = GO_STYLE_LINE | GO_STYLE_FILL;
 
 	gog_xyz_plot_klass->third_axis = GOG_AXIS_Z;
 	gog_xyz_plot_klass->build_matrix = gog_surface_plot_build_matrix;
@@ -95,7 +96,7 @@ gog_surface_plot_init (GogSurfacePlot *surface)
 
 GSF_DYNAMIC_CLASS (GogSurfacePlot, gog_surface_plot,
 	gog_surface_plot_class_init, gog_surface_plot_init,
-	GOG_XYZ_PLOT_TYPE)
+	GOG_TYPE_XYZ_PLOT)
 
 /*****************************************************************************/
 
@@ -128,9 +129,9 @@ gog_surface_view_render (GogView *view, GogViewAllocation const *bbox)
 	int i, imax, j, jmax, max, nbvalid;
 	double x, y, z, x0, y0, x1, y1;
 	GogRenderer *rend = view->renderer;
-	GogStyle *style;
+	GOStyle *style;
 	double *data;
-	GODataVector *x_vec = NULL, *y_vec = NULL;
+	GOData *x_vec = NULL, *y_vec = NULL;
 	gboolean xdiscrete, ydiscrete;
 	gboolean cw;
 	GSList *tiles = NULL, *cur;
@@ -147,7 +148,7 @@ gog_surface_view_render (GogView *view, GogViewAllocation const *bbox)
 		imax = plot->columns;
 		jmax = plot->rows;
 	}
-	if (imax ==0 || jmax == 0)
+	if (imax == 0 || jmax == 0)
 		return;
 	area = gog_chart_view_get_plot_area (view->parent);
 
@@ -167,8 +168,7 @@ gog_surface_view_render (GogView *view, GogViewAllocation const *bbox)
 		return;
 	}
 
-
-	style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
+	style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
 
 	/* Build the tiles list */
 	x_vec = gog_xyz_plot_get_x_vals (plot);
@@ -185,15 +185,15 @@ gog_surface_view_render (GogView *view, GogViewAllocation const *bbox)
 				x0 = i;
 				x1 = i + 1;
 			} else {
-				x0 = go_data_vector_get_value (x_vec, i - 1);
-				x1 = go_data_vector_get_value (x_vec, i);
+				x0 = go_data_get_vector_value (x_vec, i - 1);
+				x1 = go_data_get_vector_value (x_vec, i);
 			}
 			if (ydiscrete) {
 				y0 = j;
 				y1 = j + 1;
 			} else {
-				y0 = go_data_vector_get_value (y_vec, j - 1);
-				y1 = go_data_vector_get_value (y_vec, j);
+				y0 = go_data_get_vector_value (y_vec, j - 1);
+				y1 = go_data_get_vector_value (y_vec, j);
 			}
 			nbvalid = 0;
 			z = data[(j - 1) * imax + i - 1];
@@ -271,4 +271,4 @@ gog_surface_view_class_init (GogViewClass *view_klass)
 
 GSF_DYNAMIC_CLASS (GogSurfaceView, gog_surface_view,
 	gog_surface_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
+	GOG_TYPE_PLOT_VIEW)
